@@ -1,5 +1,5 @@
 /* infodoc.c -- functions which build documentation nodes.
-   $Id: infodoc.c,v 1.12 2007/07/01 21:20:30 karl Exp $
+   $Id: infodoc.c,v 1.14 2007/08/26 12:58:56 karl Exp $
 
    Copyright (C) 1993, 1997, 1998, 1999, 2001, 2002, 2003, 2004, 2006, 2007
    Free Software Foundation, Inc.
@@ -58,12 +58,15 @@ static char *info_internal_help_text[] = {
               Picking a menu item causes another node to be selected.\n"),
   N_("\\%-10[xref-item]  Follow a cross reference.  Reads name of reference.\n"),
   N_("\\%-10[history-node]  Move to the last node seen in this window.\n"),
-  N_("\\%-10[move-to-next-xref]  Skip to next hypertext link within this node.\n"),
-  N_("\\%-10[move-to-prev-xref]  Skip to previous hypertext link within this node.\n"),
+  N_("\\%-10[move-to-next-xref]  Skip to next hypertext link [*].\n"),
+  N_("\\%-10[move-to-prev-xref]  Skip to previous hypertext link [*].\n"),
   N_("\\%-10[select-reference-this-line]  Follow the hypertext link under cursor.\n"),
   N_("\\%-10[dir-node]  Move to the `directory' node.  Equivalent to `\\[goto-node] (DIR)'.\n"),
   N_("\\%-10[top-node]  Move to the Top node.  Equivalent to `\\[goto-node] Top'.\n"),
   "\n",
+  N_("[*]    Command acts within this node or the entire document, depending on\n"
+     "the value of cursor-movement-scrolls variable\n"),
+  "\n",
   N_("Moving within a node:\n\
 ---------------------\n"),
   N_("\\%-10[beginning-of-node]  Go to the beginning of this node.\n"),
@@ -75,8 +78,8 @@ static char *info_internal_help_text[] = {
   "\n",
   N_("Other commands:\n\
 ---------------\n"),
-  N_("\\%-10[menu-digit]  Pick first ... ninth item in node's menu.\n"),
-  N_("\\%-10[last-menu-item]  Pick last item in node's menu.\n"),
+  N_("1...9       Pick first...ninth item in this node's menu.\n"),
+  N_("\\%-10[last-menu-item]  Pick last item in this node's menu.\n"),
   N_("\\%-10[index-search]  Search for a specified string in the index entries of this Info\n\
               file, and select the node referenced by the first entry found.\n"),
   N_("\\%-10[goto-node]  Move to node specified by name.\n\
